@@ -9,7 +9,11 @@
 class CompressorUi : public Gtk::Grid, public PluginUiBase {
  public:
   CompressorUi(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder, const std::string& settings_name);
-  virtual ~CompressorUi();
+  CompressorUi(const CompressorUi&) = delete;
+  auto operator=(const CompressorUi&) -> CompressorUi& = delete;
+  CompressorUi(const CompressorUi&&) = delete;
+  auto operator=(const CompressorUi &&) -> CompressorUi& = delete;
+  ~CompressorUi() override;
 
   void on_new_reduction(double value);
 
@@ -21,10 +25,14 @@ class CompressorUi : public Gtk::Grid, public PluginUiBase {
   Glib::RefPtr<Gtk::Adjustment> attack, release, threshold, knee, ratio, makeup, preamp, reactivity, lookahead,
       input_gain, output_gain;
 
-  Gtk::LevelBar *reduction, *sidechain, *curve;
-  Gtk::Label *reduction_label, *sidechain_label, *curve_label;
-  Gtk::ComboBoxText *compression_mode, *sidechain_type, *sidechain_mode, *sidechain_source;
-  Gtk::ToggleButton* listen;
+  Gtk::LevelBar *reduction = nullptr, *sidechain = nullptr, *curve = nullptr;
+
+  Gtk::Label *reduction_label = nullptr, *sidechain_label = nullptr, *curve_label = nullptr;
+
+  Gtk::ComboBoxText *compression_mode = nullptr, *sidechain_type = nullptr, *sidechain_mode = nullptr,
+                    *sidechain_source = nullptr;
+
+  Gtk::ToggleButton* listen = nullptr;
 };
 
 #endif
