@@ -7,7 +7,11 @@
 class DelayUi : public Gtk::Grid, public PluginUiBase {
  public:
   DelayUi(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder, const std::string& settings_name);
-  virtual ~DelayUi();
+  DelayUi(const DelayUi&) = delete;
+  auto operator=(const DelayUi&) -> DelayUi& = delete;
+  DelayUi(const DelayUi&&) = delete;
+  auto operator=(const DelayUi &&) -> DelayUi& = delete;
+  ~DelayUi() override;
 
  private:
   Glib::RefPtr<Gtk::Adjustment> input_gain, output_gain, time_l, time_r;
