@@ -23,10 +23,10 @@ class EqualizerPreset : public PluginPresetBase {
             const std::string& section,
             const Glib::RefPtr<Gio::Settings>& settings) override;
 
-  void save_channel(boost::property_tree::ptree& root,
-                    const std::string& section,
-                    const Glib::RefPtr<Gio::Settings>& settings,
-                    const int& nbands);
+  static void save_channel(boost::property_tree::ptree& root,
+                           const std::string& section,
+                           const Glib::RefPtr<Gio::Settings>& settings,
+                           const int& nbands);
 
   void load_channel(boost::property_tree::ptree& root,
                     const std::string& section,
