@@ -9,13 +9,18 @@
 class FilterUi : public Gtk::Grid, public PluginUiBase {
  public:
   FilterUi(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder, const std::string& settings_name);
-  virtual ~FilterUi();
+  FilterUi(const FilterUi&) = delete;
+  auto operator=(const FilterUi&) -> FilterUi& = delete;
+  FilterUi(const FilterUi&&) = delete;
+  auto operator=(const FilterUi &&) -> FilterUi& = delete;
+  ~FilterUi() override;
 
  private:
   Glib::RefPtr<Gtk::Adjustment> input_gain, output_gain, frequency, resonance, inertia;
 
-  Gtk::ComboBoxText* mode;
-  Gtk::Button *preset_muted, *preset_disco, *preset_distant_headphones, *preset_default;
+  Gtk::ComboBoxText* mode = nullptr;
+  Gtk::Button *preset_muted = nullptr, *preset_disco = nullptr, *preset_distant_headphones = nullptr,
+              *preset_default = nullptr;
 
   void init_presets_buttons();
 };
