@@ -10,7 +10,11 @@
 class MultibandGateUi : public Gtk::Grid, public PluginUiBase {
  public:
   MultibandGateUi(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder, const std::string& settings_name);
-  virtual ~MultibandGateUi();
+  MultibandGateUi(const MultibandGateUi&) = delete;
+  auto operator=(const MultibandGateUi&) -> MultibandGateUi& = delete;
+  MultibandGateUi(const MultibandGateUi&&) = delete;
+  auto operator=(const MultibandGateUi &&) -> MultibandGateUi& = delete;
+  ~MultibandGateUi() override;
 
   void on_new_output0(double value);
   void on_new_output1(double value);
@@ -28,12 +32,20 @@ class MultibandGateUi : public Gtk::Grid, public PluginUiBase {
   Glib::RefPtr<Gtk::Adjustment> range1, attack1, release1, threshold1, knee1, ratio1, makeup1;
   Glib::RefPtr<Gtk::Adjustment> range2, attack2, release2, threshold2, knee2, ratio2, makeup2;
   Glib::RefPtr<Gtk::Adjustment> range3, attack3, release3, threshold3, knee3, ratio3, makeup3;
-  Gtk::LevelBar *output0, *output1, *output2, *output3;
-  Gtk::Label *output0_label, *output1_label, *output2_label, *output3_label;
-  Gtk::LevelBar *gating0, *gating1, *gating2, *gating3;
-  Gtk::Label *gating0_label, *gating1_label, *gating2_label, *gating3_label;
-  Gtk::ComboBoxText *mode, *detection0, *detection1, *detection2, *detection3;
-  Gtk::ToggleButton *bypass0, *bypass1, *bypass2, *bypass3, *solo0, *solo1, *solo2, *solo3;
+
+  Gtk::LevelBar *output0 = nullptr, *output1 = nullptr, *output2 = nullptr, *output3 = nullptr;
+
+  Gtk::Label *output0_label = nullptr, *output1_label = nullptr, *output2_label = nullptr, *output3_label = nullptr;
+
+  Gtk::LevelBar *gating0 = nullptr, *gating1 = nullptr, *gating2 = nullptr, *gating3 = nullptr;
+
+  Gtk::Label *gating0_label = nullptr, *gating1_label = nullptr, *gating2_label = nullptr, *gating3_label = nullptr;
+
+  Gtk::ComboBoxText *mode = nullptr, *detection0 = nullptr, *detection1 = nullptr, *detection2 = nullptr,
+                    *detection3 = nullptr;
+
+  Gtk::ToggleButton *bypass0 = nullptr, *bypass1 = nullptr, *bypass2 = nullptr, *bypass3 = nullptr, *solo0 = nullptr,
+                    *solo1 = nullptr, *solo2 = nullptr, *solo3 = nullptr;
 };
 
 #endif
