@@ -8,10 +8,14 @@
 class PitchUi : public Gtk::Grid, public PluginUiBase {
  public:
   PitchUi(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder, const std::string& settings_name);
-  virtual ~PitchUi();
+  PitchUi(const PitchUi&) = delete;
+  auto operator=(const PitchUi&) -> PitchUi& = delete;
+  PitchUi(const PitchUi&&) = delete;
+  auto operator=(const PitchUi &&) -> PitchUi& = delete;
+  ~PitchUi() override;
 
  private:
-  Gtk::ToggleButton *faster, *formant_preserving;
+  Gtk::ToggleButton *faster = nullptr, *formant_preserving = nullptr;
 
   Glib::RefPtr<Gtk::Adjustment> cents, crispness, semitones, octaves, input_gain, output_gain;
 };
