@@ -4,13 +4,14 @@
 #include <gio/gio.h>
 #include <gst/gst.h>
 #include <sigc++/sigc++.h>
-#include <array>
-#include <iostream>
-#include <mutex>
 
 class PluginBase {
  public:
-  PluginBase(const std::string& tag, const std::string& plugin_name, const std::string& schema);
+  PluginBase(std::string tag, std::string plugin_name, const std::string& schema);
+  PluginBase(const PluginBase&) = delete;
+  auto operator=(const PluginBase&) -> PluginBase& = delete;
+  PluginBase(const PluginBase&&) = delete;
+  auto operator=(const PluginBase &&) -> PluginBase& = delete;
   virtual ~PluginBase();
 
   std::string log_tag, name;
@@ -24,7 +25,7 @@ class PluginBase {
  protected:
   GSettings* settings = nullptr;
 
-  bool is_installed(GstElement* e);
+  auto is_installed(GstElement* e) -> bool;
 };
 
 #endif
