@@ -1,4 +1,5 @@
 #include "source_output_effects.hpp"
+#include <cstring>
 #include "pipeline_common.hpp"
 
 namespace {
@@ -6,26 +7,26 @@ namespace {
 void on_message_element(const GstBus* gst_bus, GstMessage* message, SourceOutputEffects* soe) {
   auto src_name = GST_OBJECT_NAME(message->src);
 
-  if (src_name == std::string("equalizer_input_level")) {
-    soe->equalizer_input_level.emit(soe->get_peak(message));
-  } else if (src_name == std::string("equalizer_output_level")) {
-    soe->equalizer_output_level.emit(soe->get_peak(message));
-  } else if (src_name == std::string("gate_input_level")) {
-    soe->gate_input_level.emit(soe->get_peak(message));
-  } else if (src_name == std::string("gate_output_level")) {
-    soe->gate_output_level.emit(soe->get_peak(message));
-  } else if (src_name == std::string("deesser_input_level")) {
-    soe->deesser_input_level.emit(soe->get_peak(message));
-  } else if (src_name == std::string("deesser_output_level")) {
-    soe->deesser_output_level.emit(soe->get_peak(message));
-  } else if (src_name == std::string("pitch_input_level")) {
-    soe->pitch_input_level.emit(soe->get_peak(message));
-  } else if (src_name == std::string("pitch_output_level")) {
-    soe->pitch_output_level.emit(soe->get_peak(message));
-  } else if (src_name == std::string("webrtc_input_level")) {
-    soe->webrtc_input_level.emit(soe->get_peak(message));
-  } else if (src_name == std::string("webrtc_output_level")) {
-    soe->webrtc_output_level.emit(soe->get_peak(message));
+  if (std::strcmp(src_name, "equalizer_input_level") == 0) {
+    soe->equalizer_input_level.emit(SourceOutputEffects::get_peak(message));
+  } else if (std::strcmp(src_name, "equalizer_output_level") == 0) {
+    soe->equalizer_output_level.emit(SourceOutputEffects::get_peak(message));
+  } else if (std::strcmp(src_name, "gate_input_level") == 0) {
+    soe->gate_input_level.emit(SourceOutputEffects::get_peak(message));
+  } else if (std::strcmp(src_name, "gate_output_level") == 0) {
+    soe->gate_output_level.emit(SourceOutputEffects::get_peak(message));
+  } else if (std::strcmp(src_name, "deesser_input_level") == 0) {
+    soe->deesser_input_level.emit(SourceOutputEffects::get_peak(message));
+  } else if (std::strcmp(src_name, "deesser_output_level") == 0) {
+    soe->deesser_output_level.emit(SourceOutputEffects::get_peak(message));
+  } else if (std::strcmp(src_name, "pitch_input_level") == 0) {
+    soe->pitch_input_level.emit(SourceOutputEffects::get_peak(message));
+  } else if (std::strcmp(src_name, "pitch_output_level") == 0) {
+    soe->pitch_output_level.emit(SourceOutputEffects::get_peak(message));
+  } else if (std::strcmp(src_name, "webrtc_input_level") == 0) {
+    soe->webrtc_input_level.emit(SourceOutputEffects::get_peak(message));
+  } else if (std::strcmp(src_name, "webrtc_output_level") == 0) {
+    soe->webrtc_output_level.emit(SourceOutputEffects::get_peak(message));
   }
 }
 
@@ -42,14 +43,14 @@ SourceOutputEffects::SourceOutputEffects(PulseManager* pulse_manager) : Pipeline
 
   auto PULSE_SOURCE = std::getenv("PULSE_SOURCE");
 
-  if (PULSE_SOURCE) {
+  if (PULSE_SOURCE != nullptr) {
     if (pm->get_source_info(PULSE_SOURCE)) {
       set_source_monitor_name(PULSE_SOURCE);
     } else {
       set_source_monitor_name(pm->server_info.default_source_name);
     }
   } else {
-    bool use_default_source = g_settings_get_boolean(settings, "use-default-source");
+    bool use_default_source = g_settings_get_boolean(settings, "use-default-source") != 0;
 
     if (use_default_source) {
       set_source_monitor_name(pm->server_info.default_source_name);
@@ -124,7 +125,7 @@ void SourceOutputEffects::on_app_added(const std::shared_ptr<AppInfo>& app_info)
 
   auto enable_all = g_settings_get_boolean(settings, "enable-all-sourceoutputs");
 
-  if (enable_all && !app_info->connected) {
+  if ((enable_all != 0) && !app_info->connected) {
     pm->move_source_output_to_pulseeffects(app_info->name, app_info->index);
   }
 }
@@ -136,8 +137,8 @@ void SourceOutputEffects::add_plugins_to_pipeline() {
 
   g_settings_get(child_settings, "plugins", "as", &iter);
 
-  while (g_variant_iter_next(iter, "s", &name)) {
-    plugins_order.push_back(name);
+  while (g_variant_iter_next(iter, "s", &name) != 0) {
+    plugins_order.emplace_back(name);
     g_free(name);
   }
 
@@ -147,8 +148,8 @@ void SourceOutputEffects::add_plugins_to_pipeline() {
 
   g_variant_unref(gvariant);
 
-  while (g_variant_iter_next(iter, "s", &name)) {
-    default_order.push_back(name);
+  while (g_variant_iter_next(iter, "s", &name) != 0) {
+    default_order.emplace_back(name);
     g_free(name);
   }
 
@@ -162,7 +163,7 @@ void SourceOutputEffects::add_plugins_to_pipeline() {
     g_settings_reset(child_settings, "plugins");
   }
 
-  for (auto v : plugins_order) {
+  for (const auto& v : plugins_order) {
     // checking if the plugin exists. If not we reset the list to default
 
     if (std::find(default_order.begin(), default_order.end(), v) == default_order.end()) {
