@@ -1,28 +1,30 @@
 #include "spectrum_settings_ui.hpp"
+#include <cstring>
 #include "util.hpp"
 
 namespace {
 
-gboolean spectrum_type_enum_to_int(GValue* value, GVariant* variant, gpointer user_data) {
+auto spectrum_type_enum_to_int(GValue* value, GVariant* variant, gpointer user_data) -> gboolean {
   auto v = g_variant_get_string(variant, nullptr);
 
-  if (v == std::string("Bars")) {
+  if (std::strcmp(v, "Bars") == 0) {
     g_value_set_int(value, 0);
-  } else if (v == std::string("Lines")) {
+  } else if (std::strcmp(v, "Lines") == 0) {
     g_value_set_int(value, 1);
   }
 
-  return true;
+  return 1;
 }
 
-GVariant* int_to_spectrum_type_enum(const GValue* value, const GVariantType* expected_type, gpointer user_data) {
+auto int_to_spectrum_type_enum(const GValue* value, const GVariantType* expected_type, gpointer user_data)
+    -> GVariant* {
   int v = g_value_get_int(value);
 
   if (v == 0) {
     return g_variant_new_string("Bars");
-  } else {
-    return g_variant_new_string("Lines");
   }
+
+  return g_variant_new_string("Lines");
 }
 
 }  // namespace
@@ -143,7 +145,7 @@ void SpectrumSettingsUi::add_to_stack(Gtk::Stack* stack, Application* app) {
   stack->add(*ui, "settings_spectrum", _("Spectrum"));
 }
 
-bool SpectrumSettingsUi::on_show_spectrum(bool state) {
+auto SpectrumSettingsUi::on_show_spectrum(bool state) -> bool {
   if (state) {
     app->sie->enable_spectrum();
     app->soe->enable_spectrum();
@@ -155,7 +157,7 @@ bool SpectrumSettingsUi::on_show_spectrum(bool state) {
   return false;
 }
 
-bool SpectrumSettingsUi::on_use_custom_color(bool state) {
+auto SpectrumSettingsUi::on_use_custom_color(bool state) -> bool {
   if (state) {
     Glib::Variant<std::vector<double>> v;
 
