@@ -1,115 +1,127 @@
 #include "webrtc_ui.hpp"
+#include <cstring>
 
 namespace {
 
-gboolean echo_suppression_level_to_int(GValue* value, GVariant* variant, gpointer user_data) {
+auto echo_suppression_level_to_int(GValue* value, GVariant* variant, gpointer user_data) -> gboolean {
   auto v = g_variant_get_string(variant, nullptr);
 
-  if (v == std::string("low")) {
+  if (std::strcmp(v, "low") == 0) {
     g_value_set_int(value, 0);
-  } else if (v == std::string("moderate")) {
+  } else if (std::strcmp(v, "moderate") == 0) {
     g_value_set_int(value, 1);
-  } else if (v == std::string("high")) {
+  } else if (std::strcmp(v, "high") == 0) {
     g_value_set_int(value, 2);
   }
 
-  return true;
+  return 1;
 }
 
-GVariant* int_to_echo_suppression_level(const GValue* value, const GVariantType* expected_type, gpointer user_data) {
+auto int_to_echo_suppression_level(const GValue* value, const GVariantType* expected_type, gpointer user_data)
+    -> GVariant* {
   int v = g_value_get_int(value);
 
   if (v == 0) {
     return g_variant_new_string("low");
-  } else if (v == 1) {
-    return g_variant_new_string("moderate");
-  } else {
-    return g_variant_new_string("high");
   }
+
+  if (v == 1) {
+    return g_variant_new_string("moderate");
+  }
+
+  return g_variant_new_string("high");
 }
 
-gboolean noise_suppression_level_to_int(GValue* value, GVariant* variant, gpointer user_data) {
+auto noise_suppression_level_to_int(GValue* value, GVariant* variant, gpointer user_data) -> gboolean {
   auto v = g_variant_get_string(variant, nullptr);
 
-  if (v == std::string("low")) {
+  if (std::strcmp(v, "low") == 0) {
     g_value_set_int(value, 0);
-  } else if (v == std::string("moderate")) {
+  } else if (std::strcmp(v, "moderate") == 0) {
     g_value_set_int(value, 1);
-  } else if (v == std::string("high")) {
+  } else if (std::strcmp(v, "high") == 0) {
     g_value_set_int(value, 2);
-  } else if (v == std::string("very-high")) {
+  } else if (std::strcmp(v, "very-high") == 0) {
     g_value_set_int(value, 3);
   }
 
-  return true;
+  return 1;
 }
 
-GVariant* int_to_noise_suppression_level(const GValue* value, const GVariantType* expected_type, gpointer user_data) {
+auto int_to_noise_suppression_level(const GValue* value, const GVariantType* expected_type, gpointer user_data)
+    -> GVariant* {
   int v = g_value_get_int(value);
 
   if (v == 0) {
     return g_variant_new_string("low");
-  } else if (v == 1) {
-    return g_variant_new_string("moderate");
-  } else if (v == 2) {
-    return g_variant_new_string("high");
-  } else {
-    return g_variant_new_string("very-high");
   }
+
+  if (v == 1) {
+    return g_variant_new_string("moderate");
+  }
+
+  if (v == 2) {
+    return g_variant_new_string("high");
+  }
+
+  return g_variant_new_string("very-high");
 }
 
-gboolean gain_control_mode_to_int(GValue* value, GVariant* variant, gpointer user_data) {
+auto gain_control_mode_to_int(GValue* value, GVariant* variant, gpointer user_data) -> gboolean {
   auto v = g_variant_get_string(variant, nullptr);
 
-  if (v == std::string("adaptive-digital")) {
+  if (std::strcmp(v, "adaptive-digital") == 0) {
     g_value_set_int(value, 0);
-  } else if (v == std::string("fixed-digital")) {
+  } else if (std::strcmp(v, "fixed-digital") == 0) {
     g_value_set_int(value, 1);
   }
 
-  return true;
+  return 1;
 }
 
-GVariant* int_to_gain_control_mode(const GValue* value, const GVariantType* expected_type, gpointer user_data) {
+auto int_to_gain_control_mode(const GValue* value, const GVariantType* expected_type, gpointer user_data) -> GVariant* {
   int v = g_value_get_int(value);
 
   if (v == 0) {
     return g_variant_new_string("adaptive-digital");
-  } else {
-    return g_variant_new_string("fixed-digital");
   }
+
+  return g_variant_new_string("fixed-digital");
 }
 
-gboolean voice_detection_likelihood_to_int(GValue* value, GVariant* variant, gpointer user_data) {
+auto voice_detection_likelihood_to_int(GValue* value, GVariant* variant, gpointer user_data) -> gboolean {
   auto v = g_variant_get_string(variant, nullptr);
 
-  if (v == std::string("very-low")) {
+  if (std::strcmp(v, "very-low") == 0) {
     g_value_set_int(value, 0);
-  } else if (v == std::string("low")) {
+  } else if (std::strcmp(v, "low") == 0) {
     g_value_set_int(value, 1);
-  } else if (v == std::string("moderate")) {
+  } else if (std::strcmp(v, "moderate") == 0) {
     g_value_set_int(value, 2);
-  } else if (v == std::string("high")) {
+  } else if (std::strcmp(v, "high") == 0) {
     g_value_set_int(value, 3);
   }
 
-  return true;
+  return 1;
 }
 
-GVariant* int_to_voice_detection_likelihood(const GValue* value,
-                                            const GVariantType* expected_type,
-                                            gpointer user_data) {
+auto int_to_voice_detection_likelihood(const GValue* value, const GVariantType* expected_type, gpointer user_data)
+    -> GVariant* {
   int v = g_value_get_int(value);
 
   if (v == 0) {
     return g_variant_new_string("very-low");
-  } else if (v == 1) {
-    return g_variant_new_string("low");
-  } else if (v == 2) {
-    return g_variant_new_string("moderate");
-  } else {
-    return g_variant_new_string("high");
   }
+
+  if (v == 1) {
+    return g_variant_new_string("low");
+  }
+
+  if (v == 2) {
+    return g_variant_new_string("moderate");
+  }
+
+  return g_variant_new_string("high");
 }
 
 }  // namespace
